@@ -1,7 +1,7 @@
 /*
 * Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
 * Copyright 2014  Hugo Pereira Da Costa <hugo.pereira@free.fr>
-* Copyright 2018  Vlad Zagorodniy <vladzzag@gmail.com>
+* Copyright 2018  Vlad Zagorodniy <vlad.zahorodnii@kde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
@@ -45,6 +45,7 @@
 #include <QPainter>
 #include <QTextStream>
 #include <QTimer>
+#include <QVariantAnimation>
 
 #if BREEZE_HAVE_X11
 #include <QX11Info>
@@ -159,7 +160,7 @@ namespace Breeze
     //________________________________________________________________
     Decoration::Decoration(QObject *parent, const QVariantList &args)
         : KDecoration2::Decoration(parent, args)
-        , m_animation( new QPropertyAnimation( this ) )
+        , m_animation( new QVariantAnimation( this ) )
     {
         g_sDecoCount++;
     }
@@ -193,7 +194,7 @@ namespace Breeze
 
         auto c = client().data();
         if( hideTitleBar() ) return c->color( ColorGroup::Inactive, ColorRole::TitleBar );
-        else if( m_animation->state() == QPropertyAnimation::Running )
+        else if( m_animation->state() == QAbstractAnimation::Running )
         {
             return KColorUtils::mix(
                 c->color( ColorGroup::Inactive, ColorRole::TitleBar ),
@@ -209,7 +210,7 @@ namespace Breeze
 
         auto c( client().data() );
         if( !m_internalSettings->drawTitleBarSeparator() ) return QColor();
-        if( m_animation->state() == QPropertyAnimation::Running )
+        if( m_animation->state() == QAbstractAnimation::Running )
         {
             QColor color( c->palette().color( QPalette::Highlight ) );
             color.setAlpha( color.alpha()*m_opacity );
@@ -223,7 +224,7 @@ namespace Breeze
     {
 
         auto c = client().data();
-        if( m_animation->state() == QPropertyAnimation::Running )
+        if( m_animation->state() == QAbstractAnimation::Running )
         {
             return KColorUtils::mix(
                 c->color( ColorGroup::Inactive, ColorRole::Foreground ),
@@ -239,11 +240,13 @@ namespace Breeze
         auto c = client().data();
 
         // active state change animation
-        m_animation->setStartValue( 0 );
+        // It is important start and end value are of the same type, hence 0.0 and not just 0
+        m_animation->setStartValue( 0.0 );
         m_animation->setEndValue( 1.0 );
-        m_animation->setTargetObject( this );
-        m_animation->setPropertyName( "opacity" );
         m_animation->setEasingCurve( QEasingCurve::InOutQuad );
+        connect(m_animation, &QVariantAnimation::valueChanged, this, [this](const QVariant &value) {
+            setOpacity(value.toReal());
+        });
 
         reconfigure();
         updateTitleBar();
@@ -310,8 +313,8 @@ namespace Breeze
         {
 
             auto c = client().data();
-            m_animation->setDirection( c->isActive() ? QPropertyAnimation::Forward : QPropertyAnimation::Backward );
-            if( m_animation->state() != QPropertyAnimation::Running ) m_animation->start();
+            m_animation->setDirection( c->isActive() ? QAbstractAnimation::Forward : QAbstractAnimation::Backward );
+            if( m_animation->state() != QAbstractAnimation::Running ) m_animation->start();
 
         } else {
 
